==> mongodb-5.0.31.gh.tar.gz: mongo-r5.0.31/src/mongo/unittest/ensure_fcv.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/server_options.h"

namespace mongo {
namespace unittest {

/**
 * Helper class for tests to set FCV to their desired version. Will unset
 * FCV when its destructor runs.
 */
class EnsureFCV {
public:
    using Version = ServerGlobalParams::FeatureCompatibility::Version;
    EnsureFCV(Version version)
        : _origVersion(serverGlobalParams.featureCompatibility.getVersion()) {
        serverGlobalParams.mutableFeatureCompatibility.setVersion(version);
    }
    ~EnsureFCV() {
        serverGlobalParams.mutableFeatureCompatibility.setVersion(_origVersion);
    }

private:
    const Version _origVersion;
};

}  // namespace unittest
}  // namespace mongo

==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/src/mongo/unittest/ensure_fcv.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/server_options.h"

namespace mongo {
namespace unittest {

/**
 * Helper class for tests to set FCV to their desired version. Will unset
 * FCV when its destructor runs.
 */
class EnsureFCV {
public:
    using Version = multiversion::FeatureCompatibilityVersion;
    EnsureFCV(Version version)
        : _origVersion(serverGlobalParams.featureCompatibility.getVersion()) {
        serverGlobalParams.mutableFeatureCompatibility.setVersion(version);
    }
    ~EnsureFCV() {
        serverGlobalParams.mutableFeatureCompatibility.setVersion(_origVersion);
    }

private:
    const Version _origVersion;
};

}  // namespace unittest
}  // namespace mongo
